@@ -1,24 +1,23 @@
 <?php
 /**
- * @author Arthur Schiwon <blizzz@owncloud.com>
+ * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bart Visscher <bartv@thisnet.nl>
- * @author Björn Schießle <schiessle@owncloud.com>
+ * @author Björn Schießle <bjoern@schiessle.org>
  * @author Craig Morrissey <craig@owncloud.com>
  * @author dampfklon <me@dampfklon.de>
  * @author Felix Böhm <felixboehm@gmx.de>
  * @author Joas Schilling <nickvergessen@owncloud.com>
- * @author Jörn Friedrich Dreyer <jfd@butonic.de>
- * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Leonardo Diez <leio10@users.noreply.github.com>
+ * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Ramiro Aparicio <rapariciog@gmail.com>
  * @author Robin Appelman <icewind@owncloud.com>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
+ * @author Roeland Jago Douma <rullzer@owncloud.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Thomas Tanghus <thomas@tanghus.net>
- * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2015, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -35,6 +34,8 @@
  *
  */
 
+use OCP\IUser;
+
 OC_JSON::checkLoggedIn();
 OCP\JSON::callCheck();
 
@@ -42,92 +43,6 @@ $defaults = new \OCP\Defaults();
 
 if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSource'])) {
 	switch ($_POST['action']) {
-		case 'share':
-			if (isset($_POST['shareType']) && isset($_POST['shareWith']) && isset($_POST['permissions'])) {
-				try {
-					$shareType = (int)$_POST['shareType'];
-					$shareWith = $_POST['shareWith'];
-					$itemSourceName = isset($_POST['itemSourceName']) ? (string)$_POST['itemSourceName'] : null;
-
-					/*
-					 * Nasty nasty fix for https://github.com/owncloud/core/issues/19950
-					 */
-					$passwordChanged = null;
-					if (is_array($shareWith)) {
-						$passwordChanged = ($shareWith['passwordChanged'] === 'true');
-						if ($shareType === OCP\Share::SHARE_TYPE_LINK && $shareWith['password'] === '') {
-							$shareWith = null;
-						} else {
-							$shareWith = $shareWith['password'];
-						}
-					} else {
-						/*
-						 * We need this branch since the calendar and contacts also use this
-						 * endpoint
-						 */
-						if ($shareType === OCP\Share::SHARE_TYPE_LINK && $shareWith === '') {
-							$shareWith = null;
-						}
-					}
-
- 					$itemSourceName=(isset($_POST['itemSourceName'])) ? (string)$_POST['itemSourceName']:'';
-
-					$token = OCP\Share::shareItem(
-						$_POST['itemType'],
-						$_POST['itemSource'],
-						$shareType,
-						$shareWith,
-						$_POST['permissions'],
-						$itemSourceName,
-						(!empty($_POST['expirationDate']) ? new \DateTime((string)$_POST['expirationDate']) : null),
-						$passwordChanged
-					);
-
-					if (is_string($token)) {
-						OC_JSON::success(array('data' => array('token' => $token)));
-					} else {
-						OC_JSON::success();
-					}
-				} catch (\OC\HintException $exception) {
-					OC_JSON::error(array('data' => array('message' => $exception->getHint())));
-				} catch (Exception $exception) {
-					OC_JSON::error(array('data' => array('message' => $exception->getMessage())));
-				}
-			}
-			break;
-		case 'unshare':
-			if (isset($_POST['shareType']) && isset($_POST['shareWith'])) {
-				if ((int)$_POST['shareType'] === OCP\Share::SHARE_TYPE_LINK && $_POST['shareWith'] == '') {
-					$shareWith = null;
-				} else {
-					$shareWith = (string)$_POST['shareWith'];
-				}
-				$return = OCP\Share::unshare((string)$_POST['itemType'],(string) $_POST['itemSource'], (int)$_POST['shareType'], $shareWith);
-				($return) ? OC_JSON::success() : OC_JSON::error();
-			}
-			break;
-		case 'setPermissions':
-			if (isset($_POST['shareType']) && isset($_POST['shareWith']) && isset($_POST['permissions'])) {
-				$return = OCP\Share::setPermissions(
-					(string)$_POST['itemType'],
-					(string)$_POST['itemSource'],
-					(int)$_POST['shareType'],
-					(string)$_POST['shareWith'],
-					(int)$_POST['permissions']
-				);
-				($return) ? OC_JSON::success() : OC_JSON::error();
-			}
-			break;
-		case 'setExpirationDate':
-			if (isset($_POST['date'])) {
-				try {
-					$return = OCP\Share::setExpirationDate((string)$_POST['itemType'], (string)$_POST['itemSource'], (string)$_POST['date']);
-					($return) ? OC_JSON::success() : OC_JSON::error();
-				} catch (\Exception $e) {
-					OC_JSON::error(array('data' => array('message' => $e->getMessage())));
-				}
-			}
-			break;
 		case 'informRecipients':
 			$l = \OC::$server->getL10N('core');
 			$shareType = (int) $_POST['shareType'];
@@ -135,21 +50,28 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 			$itemSource = (string)$_POST['itemSource'];
 			$recipient = (string)$_POST['recipient'];
 
+			$userManager = \OC::$server->getUserManager();
+			$recipientList = [];
 			if($shareType === \OCP\Share::SHARE_TYPE_USER) {
-				$recipientList[] = $recipient;
+				$recipientList[] = $userManager->get($recipient);
 			} elseif ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
 				$recipientList = \OC_Group::usersInGroup($recipient);
+				$group = \OC::$server->getGroupManager()->get($recipient);
+				$recipientList = $group->searchUsers('');
 			}
 			// don't send a mail to the user who shared the file
-			$recipientList = array_diff($recipientList, array(\OCP\User::getUser()));
+			$recipientList = array_filter($recipientList, function($user) {
+				/** @var IUser $user */
+				return $user->getUID() !== \OCP\User::getUser();
+			});
 
 			$mailNotification = new \OC\Share\MailNotifications(
-				\OC::$server->getUserSession()->getUser()->getUID(),
-				\OC::$server->getConfig(),
+				\OC::$server->getUserSession()->getUser(),
 				\OC::$server->getL10N('lib'),
 				\OC::$server->getMailer(),
 				\OC::$server->getLogger(),
-				$defaults
+				$defaults,
+				\OC::$server->getURLGenerator()
 			);
 			$result = $mailNotification->sendInternalShareMail($recipientList, $itemSource, $itemType);
 
@@ -183,12 +105,12 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 			$to_address = (string)$_POST['toaddress'];
 
 			$mailNotification = new \OC\Share\MailNotifications(
-				\OC::$server->getUserSession()->getUser()->getUID(),
-				\OC::$server->getConfig(),
+				\OC::$server->getUserSession()->getUser(),
 				\OC::$server->getL10N('lib'),
 				\OC::$server->getMailer(),
 				\OC::$server->getLogger(),
-				$defaults
+				$defaults,
+				\OC::$server->getURLGenerator()
 			);
 
 			$expiration = null;
@@ -199,7 +121,6 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				} catch (Exception $e) {
 					\OCP\Util::writeLog('sharing', "Couldn't read date: " . $e->getMessage(), \OCP\Util::ERROR);
 				}
-
 			}
 
 			$result = $mailNotification->sendLinkShareMail($to_address, $file, $link, $expiration);
@@ -274,21 +195,13 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 					$reshare = false;
 				}
 				if ($_GET['checkShares'] == 'true') {
-					$sharesTMP = OCP\Share::getItemShared(
+					$shares = OCP\Share::getItemShared(
 						(string)$_GET['itemType'],
 						(string)$_GET['itemSource'],
 						OCP\Share::FORMAT_NONE,
 						null,
 						true
 					);
-					$ids = [];
-					$shares = [];
-					foreach($sharesTMP as $share) {
-						if (!isset($ids[$share['id']])) {
-							$ids[$share['id']] = true;
-							$shares[] = $share;
-						}
-					}
 				} else {
 					$shares = false;
 				}
@@ -317,7 +230,6 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 
 						foreach($emails as $email) {
 							$result[] = array(
-								'id' => $contact['id'],
 								'email' => $email,
 								'displayname' => $contact['FN'],
 							);
